pub fn set_event_loop_proxy(proxy: EventLoopProxy<()>)Expand description
Store the event loop proxy so tray commands / deeplinks can wake the event loop.
pub fn set_event_loop_proxy(proxy: EventLoopProxy<()>)Store the event loop proxy so tray commands / deeplinks can wake the event loop.